@@ -51,8 +51,8 @@ static void timeout_flows(struct parser_base *p, struct collector_info *info) {
 
     uint64_t total_bytes = 0;
     size_t largest_flow_size = 0;
-    struct flow *largest_inmem_flow;
-    struct flow_id *id_of_largest_inmem_flow;
+    struct flow *largest_inmem_flow = NULL;
+    struct flow_id *id_of_largest_inmem_flow = NULL;
 
     const uint64_t time = p->last_rx_time;
     kv_reset(p->collector_list);
